#!/bin/sh
source /etc/bashrc
if [ -e ./scripts/filesync.py ]; then
    sudo python ./scripts/filesync.py
else
    sudo python ./scripts/filesync.pyc
fi
